@@ -72,13 +72,6 @@ render_gray_mod(GtkWidget *a, GdkImlibImage *im, gint br)
       g_free(ptr);
     }
   
-  gdk_imlib_get_image_red_curve(im, modr);
-  gdk_imlib_get_image_green_curve(im, modg);
-  gdk_imlib_get_image_blue_curve(im, modb);
-  for (i = 0; i < 256; i++)
-    modz[i] = 
-    (unsigned char)(((int)modr[i] + (int)modg[i] + (int)modb[i]) / 3);
-  
   ptr = curve->rgb_data;
   for (y = 0; y < 64; y++)
     {
@@ -89,18 +82,31 @@ render_gray_mod(GtkWidget *a, GdkImlibImage *im, gint br)
 	  *ptr++ = 0;
 	}
     }
-  for (i = 0; i < 64; i++)
+
+  if (im) 
     {
-      val = modz[i << 2] >> 2;
-      ptr = curve->rgb_data + (64 * 3 * 63) + (i * 3);
-      for (y = 0; y < val; y++)
+      gdk_imlib_get_image_red_curve(im, modr);
+      gdk_imlib_get_image_green_curve(im, modg);
+      gdk_imlib_get_image_blue_curve(im, modb);
+
+      for (i = 0; i < 256; i++)
+	modz[i] = 
+	  (unsigned char)(((int)modr[i] + (int)modg[i] + (int)modb[i]) / 3);
+
+      for (i = 0; i < 64; i++)
 	{
-	  ptr[0] = (i << 1) + (br >> 1);
-	  ptr[1] = (i << 1) + (br >> 1);
-	  ptr[2] = (i << 1) + (br >> 1);
-	  ptr -= (64 * 3);
+	  val = modz[i << 2] >> 2;
+	  ptr = curve->rgb_data + (64 * 3 * 63) + (i * 3);
+	  for (y = 0; y < val; y++)
+	    {
+	      ptr[0] = (i << 1) + (br >> 1);
+	      ptr[1] = (i << 1) + (br >> 1);
+	      ptr[2] = (i << 1) + (br >> 1);
+	      ptr -= (64 * 3);
+	    }
 	}
     }
+
   ptr = curve->rgb_data;
   for (y = 0; y < 64; y++)
     {
@@ -153,8 +159,7 @@ render_red_mod(GtkWidget *a, GdkImlibImage *im, gint br)
       curve = gdk_imlib_create_image_from_data(ptr, NULL, 64, 64);
       g_free(ptr);
     }
-  
-  gdk_imlib_get_image_red_curve(im, modz);
+
   ptr = curve->rgb_data;
   for (y = 0; y < 64; y++)
     {
@@ -165,18 +170,24 @@ render_red_mod(GtkWidget *a, GdkImlibImage *im, gint br)
 	  *ptr++ = 0;
 	}
     }
-  for (i = 0; i < 64; i++)
+  if (im)
     {
-      val = modz[i << 2] >> 2;
-      ptr = curve->rgb_data + (64 * 3 * 63) + (i * 3);
-      for (y = 0; y < val; y++)
+      gdk_imlib_get_image_red_curve(im, modz);
+
+      for (i = 0; i < 64; i++)
 	{
-	  ptr[0] = (i << 1) + (br >> 1);
-	  ptr[1] = (y * br * i) / (val * 63);
-	  ptr[2] = (y * br * i) / (val * 63);
-	  ptr -= (64 * 3);
+	  val = modz[i << 2] >> 2;
+	  ptr = curve->rgb_data + (64 * 3 * 63) + (i * 3);
+	  for (y = 0; y < val; y++)
+	    {
+	      ptr[0] = (i << 1) + (br >> 1);
+	      ptr[1] = (y * br * i) / (val * 63);
+	      ptr[2] = (y * br * i) / (val * 63);
+	      ptr -= (64 * 3);
+	    }
 	}
     }
+
   ptr = curve->rgb_data;
   for (y = 0; y < 64; y++)
     {
@@ -230,7 +241,6 @@ render_green_mod(GtkWidget *a, GdkImlibImage *im, gint br)
       g_free(ptr);
     }
   
-  gdk_imlib_get_image_green_curve(im, modz);
   ptr = curve->rgb_data;
   for (y = 0; y < 64; y++)
     {
@@ -241,18 +251,25 @@ render_green_mod(GtkWidget *a, GdkImlibImage *im, gint br)
 	  *ptr++ = 0;
 	}
     }
-  for (i = 0; i < 64; i++)
+
+  if (im)
     {
-      val = modz[i << 2] >> 2;
-      ptr = curve->rgb_data + (64 * 3 * 63) + (i * 3);
-      for (y = 0; y < val; y++)
+      gdk_imlib_get_image_green_curve(im, modz);
+
+      for (i = 0; i < 64; i++)
 	{
-	  ptr[0] = (y * br * i) / (val * 63);
-	  ptr[1] = (i << 1) + (br >> 1);
-	  ptr[2] = (y * br * i) / (val * 63);
-	  ptr -= (64 * 3);
+	  val = modz[i << 2] >> 2;
+	  ptr = curve->rgb_data + (64 * 3 * 63) + (i * 3);
+	  for (y = 0; y < val; y++)
+	    {
+	      ptr[0] = (y * br * i) / (val * 63);
+	      ptr[1] = (i << 1) + (br >> 1);
+	      ptr[2] = (y * br * i) / (val * 63);
+	      ptr -= (64 * 3);
+	    }
 	}
     }
+
   ptr = curve->rgb_data;
   for (y = 0; y < 64; y++)
     {
@@ -306,7 +323,6 @@ render_blue_mod(GtkWidget *a, GdkImlibImage *im, gint br)
       g_free(ptr);
     }
   
-  gdk_imlib_get_image_blue_curve(im, modz);
   ptr = curve->rgb_data;
   for (y = 0; y < 64; y++)
     {
@@ -317,18 +333,25 @@ render_blue_mod(GtkWidget *a, GdkImlibImage *im, gint br)
 	  *ptr++ = 0;
 	}
     }
-  for (i = 0; i < 64; i++)
+
+  if (im)
     {
-      val = modz[i << 2] >> 2;
-      ptr = curve->rgb_data + (64 * 3 * 63) + (i * 3);
-      for (y = 0; y < val; y++)
+      gdk_imlib_get_image_blue_curve(im, modz);
+
+      for (i = 0; i < 64; i++)
 	{
-	  ptr[0] = (y * br * i) / (val * 63);
-	  ptr[1] = (y * br * i) / (val * 63);
-	  ptr[2] = (i << 1) + (br >> 1);
-	  ptr -= (64 * 3);
+	  val = modz[i << 2] >> 2;
+	  ptr = curve->rgb_data + (64 * 3 * 63) + (i * 3);
+	  for (y = 0; y < val; y++)
+	    {
+	      ptr[0] = (y * br * i) / (val * 63);
+	      ptr[1] = (y * br * i) / (val * 63);
+	      ptr[2] = (i << 1) + (br >> 1);
+	      ptr -= (64 * 3);
+	    }
 	}
     }
+
   ptr = curve->rgb_data;
   for (y = 0; y < 64; y++)
     {
@@ -1098,7 +1121,7 @@ ee_edit_new(void)
   gtk_widget_show(vm);
   gtk_container_add(GTK_CONTAINER(w), vm);
 
-  f = gtk_frame_new(_("Colour Settings"));
+  f = gtk_frame_new(_("Color Settings"));
   gtk_widget_show(f);
   gtk_box_pack_start(GTK_BOX(vm), f, TRUE, TRUE, 0);
   
@@ -1317,7 +1340,7 @@ ee_edit_new(void)
   gtk_widget_show(h);
   gtk_box_pack_start(GTK_BOX(v), h, TRUE, TRUE, 0);
   
-  l = gtk_label_new(_("Colour Modifications:"));
+  l = gtk_label_new(_("Color Modifications:"));
   gtk_widget_show(l);
   gtk_box_pack_start(GTK_BOX(h), l, FALSE, FALSE, 0);
   gtk_object_set_data(GTK_OBJECT(w), "size_label", l);
