@@ -4,6 +4,7 @@
 /* file for more information                                                 */
 /*****************************************************************************/
 
+#include <config.h>
 #include <ee_filesel.h>
 #include <ee_file.h>
 #include <stdio.h>
@@ -523,9 +524,9 @@ ee_filesel_cb_select(GtkWidget * widget, gpointer * data)
       g_snprintf(tmp, sizeof(tmp), "%ix%i", im->rgb_width, im->rgb_height);
       gtk_clist_set_text(GTK_CLIST(c), 2, 1, tmp);
       if (im->shape_color.r >= 0)
-	g_snprintf(tmp, sizeof(tmp), "Yes");
+	g_snprintf(tmp, sizeof(tmp), _("Yes"));
       else
-	g_snprintf(tmp, sizeof(tmp), "No");
+	g_snprintf(tmp, sizeof(tmp), _("No"));
       gtk_clist_set_text(GTK_CLIST(c), 4, 1, tmp);
       gdk_imlib_destroy_image(im);
     }
@@ -567,7 +568,7 @@ ee_filesel_new(void)
 
   w = gtk_window_new(GTK_WINDOW_TOPLEVEL);
   gtk_window_position(GTK_WINDOW(w), GTK_WIN_POS_MOUSE);
-  gtk_window_set_wmclass(GTK_WINDOW(w), "ee-filesel", "Image Viewer");
+  gtk_window_set_wmclass(GTK_WINDOW(w), "ee-filesel", _("Image Viewer"));
   gtk_window_set_title(GTK_WINDOW(w), _("Select a file to load"));
   gtk_container_border_width(GTK_CONTAINER(w), 2);
   gtk_window_set_policy(GTK_WINDOW(w), 0, 1, 1);
@@ -665,7 +666,7 @@ ee_filesel_new(void)
 		     w);
   gtk_menu_append(GTK_MENU(m), mi);
   gtk_widget_show(mi);
-  mi = gtk_menu_item_new_with_label("PS (PostScript)");
+  mi = gtk_menu_item_new_with_label(_("PS (PostScript)"));
   gtk_object_set_data(GTK_OBJECT(mi), "extension", "ps");
   gtk_signal_connect(GTK_OBJECT(mi),
 		     "activate", GTK_SIGNAL_FUNC(ee_filesel_cb_set_format),
@@ -693,7 +694,7 @@ ee_filesel_new(void)
 		     w);
   gtk_menu_append(GTK_MENU(m), mi);
   gtk_widget_show(mi);
-  mi = gtk_menu_item_new_with_label("Other (Automatic by extension)");
+  mi = gtk_menu_item_new_with_label(_("Other (Automatic by extension)"));
   gtk_object_set_data(GTK_OBJECT(mi), "extension", "???");
   gtk_signal_connect(GTK_OBJECT(mi),
 		     "activate", GTK_SIGNAL_FUNC(ee_filesel_cb_set_format),
@@ -911,39 +912,39 @@ ee_filesel_new(void)
   gtk_clist_set_column_width(GTK_CLIST(c), 1, 110);
   gtk_object_set_data(GTK_OBJECT(w), "info", c);
   {
-    gchar              *txt[] =
-    {"Filename:", ""};
+    gchar              *txt[] = {N_("Filename:"), ""};
 
+    txt[0]=_(txt[0]);
     gtk_clist_insert(GTK_CLIST(c), 0, txt);
   }
   {
-    gchar              *txt[] =
-    {"Format:", ""};
+    gchar              *txt[] = {N_("Format:"), ""};
 
+    txt[0]=_(txt[0]);
     gtk_clist_insert(GTK_CLIST(c), 1, txt);
   }
   {
-    gchar              *txt[] =
-    {"Dimensions:", ""};
+    gchar              *txt[] = {N_("Dimensions:"), ""};
 
+    txt[0]=_(txt[0]);
     gtk_clist_insert(GTK_CLIST(c), 2, txt);
   }
   {
-    gchar              *txt[] =
-    {"File Size:", ""};
+    gchar              *txt[] = {N_("File Size:"), ""};
 
+    txt[0]=_(txt[0]);
     gtk_clist_insert(GTK_CLIST(c), 3, txt);
   }
   {
-    gchar              *txt[] =
-    {"Has Transparency:", ""};
+    gchar              *txt[] = {N_("Has Transparency:"), ""};
 
+    txt[0]=_(txt[0]);
     gtk_clist_insert(GTK_CLIST(c), 4, txt);
   }
   {
-    gchar              *txt[] =
-    {"Last Modified Date:", ""};
+    gchar              *txt[] = {N_("Last Modified Date:"), ""};
 
+    txt[0]=_(txt[0]);
     gtk_clist_insert(GTK_CLIST(c), 5, txt);
   }
 
